# xdart
X-ray Data Analysis in Real Time

# Installation
### Recommended method:

1. Install Anaconda if you don't already have it (Miniconda recommended) <https://docs.conda.io/en/latest/miniconda.html>

2. From the terminal, create a new environment with python < 3.12:
   ```
   conda create -n xdart python=3.11
   ```

3. Activate the xdart environment:
   ```
   conda activate xdart
   ```

4. Install xdart using pip: 
   ```
   pip install xdart --upgrade
   ```

### Alternative:
If you already have conda installed and a working environment you want to use, you can simply install xdart in that environment: 
```
pip install xdart --upgrade
```

# Running
Once installed you can run the program by simply typing **xdart** in the terminal. **Important**: Make sure you have activated the conda environment xdart was installed in. 
```
conda activate xdart
xdart
```
